# Mixician

![Mixician](https://github.com/yinsn/Mixician/blob/develop/docs/images/Mixician.svg)

[![Python](https://img.shields.io/badge/python3.9-red?logo=Python&logoColor=white)](https://www.python.org)
[![PyPI](https://img.shields.io/pypi/v/mixician?color=green)](https://pypi.org/project/mixician/)
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/yinsn/Mixician)

An advanced hybrid ranking engine for recommendation systems, designed to automate the optimization of algorithms and parameters tailored to diverse objectives.

## Installation

In most cases, you can install the pre-build binaries via

```sh
pip install mixician
```
